about summary refs log tree commit diff homepage
diff options
context:
space:
mode:
authorCristian Cadar <cristic@cs.stanford.edu>2013-05-08 15:20:17 +0000
committerCristian Cadar <cristic@cs.stanford.edu>2013-05-08 15:20:17 +0000
commit772d0b11529f58a703cdceafb22742339771faf7 (patch)
treeb17e6f10c81061db2eff4ab5f8e54e7f1952aefe
parent973ca0c8affc4222c62af39deb0f5d77c3401def (diff)
downloadklee-772d0b11529f58a703cdceafb22742339771faf7.tar.gz
Patch by Dan Liew: "Renamed ExprSMTLIBPrinter method mangleQuery() to negateQueryExpression() to make it clear what it does."
git-svn-id: https://llvm.org/svn/llvm-project/klee/trunk@181445 91177308-0d34-0410-b5e6-96231b3b80d8
-rw-r--r--include/klee/util/ExprSMTLIBPrinter.h6
-rw-r--r--lib/Expr/ExprSMTLIBPrinter.cpp4
2 files changed, 5 insertions, 5 deletions
diff --git a/lib/Expr/ExprSMTLIBPrinter.cpp b/lib/Expr/ExprSMTLIBPrinter.cpp
index aa75629a..9e97a4e0 100644
--- a/lib/Expr/ExprSMTLIBPrinter.cpp
+++ b/lib/Expr/ExprSMTLIBPrinter.cpp
@@ -69,7 +69,7 @@ namespace klee
 		query = &q;
 		reset(); // clear the data structures
 		scanAll();
-		mangleQuery();
+		negateQueryExpression();
 	}
 
 	void ExprSMTLIBPrinter::reset()
@@ -831,7 +831,7 @@ namespace klee
 		*p << ")";
 	}
 
-	void ExprSMTLIBPrinter::mangleQuery()
+	void ExprSMTLIBPrinter::negateQueryExpression()
 	{
 		//Negating the query
 		queryAssert = Expr::createIsZero(query->expr);
diff --git a/include/klee/util/ExprSMTLIBPrinter.h b/include/klee/util/ExprSMTLIBPrinter.h
index 2dc65438..83f48eb6 100644
--- a/include/klee/util/ExprSMTLIBPrinter.h
+++ b/include/klee/util/ExprSMTLIBPrinter.h
@@ -224,7 +224,7 @@ namespace klee {
 			//Print SMTLIBv2 for all constraints in the query
 			virtual void printConstraints();
 
 			//Print SMTLIBv2 assert statement for the "mangled" query
 			virtual void printQuery();
 
 			///Print the SMTLIBv2 command to check satisfiability and also optionally request for values
@@ -287,7 +287,7 @@ namespace klee {
 			PrintContext* p;
 
 			///This contains the query from the solver but negated for our purposes.
-			/// \sa mangleQuery()
+			/// \sa negateQueryExpression()
 			ref<Expr> queryAssert;
 
 			///Indicates if there were any constant arrays founds during a scan()
@@ -303,7 +303,7 @@ namespace klee {
 			std::map<SMTLIBboolOptions,bool> smtlibBoolOptions;
 
 			///This sets queryAssert to be the boolean negation of the original Query
-			void mangleQuery();
+			void negateQueryExpression();
 
 			//Print a SMTLIBv2 option as a C-string
 			const char* getSMTLIBOptionString(ExprSMTLIBPrinter::SMTLIBboolOptions option);
@@ -224,7 +224,7 @@ namespace klee {
 			virtual void printConstraints();
 
-			//Print SMTLIBv2 assert statement for the "mangled" query
+			//Print SMTLIBv2 assert statement for the negated query expression
 			virtual void printQuery();
 